@@ -3,7 +3,7 @@
 ** Written by Waldemar Celes
 ** TeCGraf/PUC-Rio
 ** Aug 2003
-** $Id:$
+** $Id: tolua.c,v 1.4 2009/11/24 16:45:12 fabraham Exp $
 */
 
 /* This code is free software; you can redistribute it and/or modify it. 
@@ -62,7 +62,7 @@ static void error (char* o)
 
 int main (int argc, char* argv[])
 {
- lua_State* L = lua_open();
+ lua_State* L = luaL_newstate();
  luaL_openlibs(L);
 
  lua_pushstring(L,TOLUA_VERSION); lua_setglobal(L,"TOLUA_VERSION");
@@ -119,8 +119,11 @@ int main (int argc, char* argv[])
   p = (p==NULL) ? path : p+1;
   sprintf(p,"%s","../src/bin/lua/");
   lua_pushstring(L,path); lua_setglobal(L,"path");
-		strcat(path,"all.lua");
-  luaL_dofile(L,path); 
+  strcat(path,"all.lua");
+  if (luaL_dofile(L,path)) {
+   printf("error loading all.lua: %s\n",lua_tostring(L,-1));
+   return 1;
+  }
  }
 #endif
  return 0;
