@@ -18,7 +18,7 @@ Array* parray = &array;
 int main (void)
 {
 	int  tolua_tarray_open (lua_State*);
-	lua_State* L = lua_open();
+	lua_State* L = luaL_newstate();
 	int i;
 
 	for (i=0; i<10; ++i)
