@@ -10,13 +10,13 @@ public:
   static Tst_A* last;
   Tst_A () {last = this;}
   virtual ~Tst_A() {}
-  virtual char* a () { return "A"; }
+  virtual const char* a () { return "A"; }
   class Tst_AA
   {
  public:
     Tst_AA () {}
     virtual ~Tst_AA () { }
-    char* aa () { return "AA"; }
+    const char* aa () { return "AA"; }
   };
   class Tst_BB : public Tst_AA
   {
@@ -24,7 +24,7 @@ public:
     Tst_BB () {}
     virtual ~Tst_BB () {}
     Tst_AA* Base () { return this; }
-    char* classname () const {
+    const char* classname () const {
       return "Tst_BB";
     }
   };
@@ -36,7 +36,7 @@ public:
   static Tst_B* last;
   Tst_B () {last = this;}
   virtual ~Tst_B () { }
-  virtual char* b () { return "B"; }
+  virtual const char* b () { return "B"; }
 };
 
 class Tst_C : public Tst_B
@@ -46,7 +46,7 @@ public:
   static Tst_C* last;
   Tst_C (int n) : i(n) {last = this;}
  virtual ~Tst_C () { printf("deleting C: %d\n",i); }
-  virtual char* c () { return "C"; }
+  virtual const char* c () { return "C"; }
 };
 
 inline Tst_A::Tst_AA* Tst_create_aa ()
