@@ -10,7 +10,7 @@ extern "C"
 int main (void)
 {
 	int  tolua_tconstant_open (lua_State*);
-	lua_State* L = lua_open();
+	lua_State* L = luaL_newstate();
 	luaL_openlibs(L);
 	tolua_tconstant_open(L);
 
