@@ -14,7 +14,7 @@ Status checkenum (Order o)
 int main (void)
 {
 	int  tolua_tenum_open (lua_State*);
-	lua_State* L = lua_open();
+	lua_State* L = luaL_newstate();
 
 	luaL_openlibs(L);
 	tolua_tenum_open(L);
