@@ -12,7 +12,7 @@ int main ()
 {
 	int  tolua_tmodule_open (lua_State*);
 
-	lua_State* L = lua_open();
+	lua_State* L = luaL_newstate();
 	luaL_openlibs(L);
 	tolua_tmodule_open(L);
 
