@@ -27,7 +27,7 @@ B* mb;
 int main (void)
 {
 	int  tolua_tvariable_open (lua_State*);
-	lua_State* L = lua_open();
+	lua_State* L = luaL_newstate();
 
 	B bb = {a,NULL};
 	B bbb = {ma,&bb};
